# nblast-rs

Implementation of NBLAST for neuron morphology comparisons, originally published [here](https://www.ncbi.nlm.nih.gov/pmc/articles/PMC4961245/) and implemented [here](https://github.com/natverse/nat.nblast/).

This package is compatible with the reference implementation, but the API is subject to change.

## Benchmarking

Some benchmarks use optional features, and so benchmarkers should use

```sh
cargo bench --all-features
```
